@@ -172,6 +172,7 @@ OC.L10N.register(
     "Go to talk conversation" : "前往對話",
     "View profile" : "檢視個人檔案",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "此聯絡人的資料有問題，已修復。請審閱內容並點擊此處以儲存。",
+    "Edit profile" : "編輯個人設定",
     "Clone contact" : "複製聯絡人",
     "Generate QR Code" : "生成 QR Code",
     "Contact vCard as QR code" : "QR Code 形式的聯絡人 vCard",
@@ -254,6 +255,7 @@ OC.L10N.register(
     "Select type" : "選擇類型",
     "Add contact in group" : "新增聯絡人到群組",
     "None" : "無",
+    "copy" : "複製",
     "Select option" : "選擇選項",
     "note" : "備註",
     "email" : "電郵地址",
@@ -381,6 +383,8 @@ OC.L10N.register(
     "Unable to create team {circleName}" : "無法建立團隊 {circleName}",
     "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
     "Unable to delete contact" : "無法刪除聯絡人",
+    "Value copied to the clipboard" : "已複製數值至剪貼板",
+    "Could not copy value to the clipboard." : "無法複製數值至剪貼板",
     "Loading contacts …" : "正在載入通訊錄 …",
     "Loading …" : "正在載入 …",
     "General settings" : "一般設定",
