@@ -75,6 +75,7 @@ OC.L10N.register(
     "No users or groups" : "沒有使用者或群組",
     "Unable to delete the share" : "無法刪除這個分享",
     "Unable to change permissions" : "無法變更權限",
+    "can create and edit" : "可以建立並編輯",
     "Choose a vCard file to import" : "選取要匯入的 vCard 檔案",
     "Import into the {addressbookName} address book" : "匯入至 {addressbookName} 通訊錄",
     "Select local file" : "選取本機檔案",
@@ -171,6 +172,7 @@ OC.L10N.register(
     "Go to talk conversation" : "前往對話",
     "View profile" : "檢視個人檔案",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "此聯絡人的資料有問題，已修復。請審閱內容並點擊此處以儲存。",
+    "Edit profile" : "編輯個人檔案",
     "Clone contact" : "再製連絡人",
     "Generate QR Code" : "產生 QR Code",
     "Contact vCard as QR code" : "QR Code 形式的聯絡人 vCard",
@@ -304,6 +306,8 @@ OC.L10N.register(
     "Members can also invite" : "成員也可以邀請",
     "Membership" : "成員",
     "Prevent teams from being a member of another team" : "避免團隊成為其他團隊的成員",
+    "Federation" : "聯盟式",
+    "Allow federated members" : "允許聯盟式成員",
     "Privacy" : "隱私權",
     "Visible to everyone" : "對所有人可見",
     "users" : "使用者",
